import m from 'mithril';
import { Widget } from 'components/widgets/widget';

require('./gauge-linear.css');

export class GaugeLinear extends Widget {
	private bars: SVGRectElement[] = [];
	
	constructor(vnode: any) {
		super(vnode);
	}
	
	view(vnode: m.Vnode<{}, {}>): m.Children {
		return <div class="widget gauge-linear" style={'flex: ' + this.widgetWidth}>
			<p class="value">643<span class="unit">W</span></p>
			<svg>
			</svg>
		</div>;
	}
	
	createSvg(svgElement: SVGElement) {
		let w = Math.round(svgElement.clientWidth);
		let h = Math.round(svgElement.clientHeight);
		
		svgElement.setAttribute('viewBox', "0 0 "+w+" "+h);

		let bg = document.createElementNS('http://www.w3.org/2000/svg', 'rect');
		bg.setAttribute('width', w.toString());
		bg.setAttribute('height', h.toString());
		bg.classList.add('gauge-linear-bg');
		svgElement.append(bg);
		
		let barHeight = 15;
		const barGap = barHeight * 0.2;
		let numBars = Math.round(h / (barHeight + barGap));
		
		let bh = (h - (numBars+1)*barGap) / numBars;
		barHeight = Math.round(bh);
		
		for(let barIdx = 0; barIdx < numBars; ++barIdx) {
			let bar = document.createElementNS('http://www.w3.org/2000/svg', 'rect');
			bar.setAttribute('width', (w - barGap * 2).toString());
			bar.setAttribute('height', barHeight.toString());
			bar.classList.add('gauge-linear-bar');
			bar.classList.toggle('lit', false);
			
			bar.setAttribute('x', barGap.toString());
			bar.setAttribute('y', (h - barIdx * (bh+barGap) - barGap - barHeight).toString());
			
			svgElement.append(bar);
			
			this.bars.push(bar);
		}
	}
	
	renderGaugeRatio(ratio: number) {
		let numBars = this.bars.length;
		let litBars = Math.round(ratio * numBars);
		console.log(litBars);
		for(let barIdx = 0; barIdx < numBars; ++barIdx) {
			let bar = this.bars[barIdx];
			bar.classList.toggle('lit', barIdx < litBars);
		}
	}
	
	oncreate(vnode: any) {
		let svgElement: SVGElement = vnode.dom.querySelector('svg');
		this.createSvg(svgElement);
		this.renderGaugeRatio(0.2);
	}
}
